@@ -15,11 +15,11 @@ import index
 import show
 import search
 import agent_commands
+import discovery_commands
 import exec_commands
 import snmp_commands
 import sub_command
 
-
 TIME_FORMAT_MS = 'ms'
 TIME_FORMAT_ISO_UTC = 'iso_utc'
 TIME_FORMAT_ISO_LOCAL = 'iso_local'
@@ -34,9 +34,9 @@ SERVER_ARGS = ['pause', 'status']
 EXEC_ARGS = ['ping', 'fping', 'traceroute']
 FIND_AGENT_ARGS = ['find_agent']
 SNMP_ARGS = ['get', 'walk']
-DISCOVERY_ARGS = ['start', 'pause', 'resume', 'schedule']
+DISCOVERY_ARGS = ['start', 'pause', 'resume', 'submit', 'status']
 HUD_ARGS = ['reset']
-NSGQL_ARGS = ['rebuild']   # command "nsgql rebuild" rebuilds NsgQL dynamic schema
+NSGQL_ARGS = ['rebuild']  # command "nsgql rebuild" rebuilds NsgQL dynamic schema
 
 
 class NsgCLI(sub_command.SubCommand, object):
@@ -85,18 +85,21 @@ class NsgCLI(sub_command.SubCommand, object):
 
     ##########################################################################################
     def do_show(self, arg):
-        sub_cmd = show.ShowCommands(self.base_url, self.token, self.netid, time_format=self.time_format, region=self.current_region)
+        sub_cmd = show.ShowCommands(self.base_url, self.token, self.netid, time_format=self.time_format,
+                                    region=self.current_region)
         if arg:
             sub_cmd.onecmd(arg)
         else:
             sub_cmd.cmdloop()
 
     def help_show(self):
-        sub_cmd = show.ShowCommands(self.base_url, self.token, self.netid, time_format=self.time_format, region=self.current_region)
+        sub_cmd = show.ShowCommands(self.base_url, self.token, self.netid, time_format=self.time_format,
+                                    region=self.current_region)
         return sub_cmd.help()
 
     def complete_show(self, text, _line, _begidx, _endidx):
-        sub_cmd = show.ShowCommands(self.base_url, self.token, self.netid, time_format=self.time_format, region=self.current_region)
+        sub_cmd = show.ShowCommands(self.base_url, self.token, self.netid, time_format=self.time_format,
+                                    region=self.current_region)
         return sub_cmd.completedefault(text, _line, _begidx, _endidx)
 
     ##########################################################################################
@@ -202,44 +205,19 @@ class NsgCLI(sub_command.SubCommand, object):
                                  that do not implement incremental discovery
         discovery pause
         discovery resume
-        discovery schedule deviceID
+        discovery schedule device1 device2 device3   where each device is identified by device ID, name, sysName or address
 
         :param arg: command, possibly with argument (separated by space)
         """
-        try:
-            if ' ' in arg:
-                comps = arg.split(' ')
-                if comps[0] == 'schedule':
-                    dev_id = int(comps[1])
-                    request = 'v2/nsg/discovery/net/{0}/schedule/{1}'.format(self.netid, dev_id)
-                    response = self.basic_command(request)
-                    self.print_response(response)
-                else:
-                    print('Unsupported command "discovery {}"'.format(arg))
-                return
-            elif arg == 'pause':
-                request = 'v2/nsg/discovery/net/{0}/pause'.format(self.netid)
-                response = self.basic_command(request)
-                self.print_response(response)
-            elif arg == 'resume':
-                request = 'v2/nsg/discovery/net/{0}/resume'.format(self.netid)
-                response = self.basic_command(request)
-                self.print_response(response)
-            elif arg == 'start':
-                print('WARNING: command "discovery start" has been deprecated and is supported only for backward '
-                      'compatibility with NSG clusters that do not support incremental discovery')
-                request = 'v2/nsg/discovery/net/{0}/start'.format(self.netid)
-                response = self.basic_command(request)
-                if response is not None:
-                    self.print_response(response)
-            else:
-                print('Invalid argument "{0}"'.format(arg))
-        except ValueError as e:
-            # arg is not a number, try other commands
-            pass
+        sub_cmd = discovery_commands.DiscoveryCommands(self.base_url, self.token, self.netid, self.time_format)
+        if not arg:
+            sub_cmd.cmdloop()
+        else:
+            sub_cmd.onecmd(arg)
 
     def help_discovery(self):
-        print('Operations with network discovery. Supported arguments: {0}'.format(DISCOVERY_ARGS))
+        sub_cmd = discovery_commands.DiscoveryCommands(self.base_url, self.token, self.netid, self.time_format)
+        sub_cmd.help()
 
     def complete_discovery(self, text, _line, _begidx, _endidx):
         return self.complete_cmd(text, DISCOVERY_ARGS)
@@ -416,10 +394,12 @@ class NsgCLI(sub_command.SubCommand, object):
             agent_name = args.pop(0)
             work_args = ' '.join(args)
         if not work_args:
-            sub_cmd = agent_commands.AgentCommands(agent_name, self.base_url, self.token, self.netid, region=self.current_region)
+            sub_cmd = agent_commands.AgentCommands(agent_name, self.base_url, self.token, self.netid,
+                                                   region=self.current_region)
             sub_cmd.cmdloop()
         else:
-            sub_cmd = agent_commands.AgentCommands(agent_name, self.base_url, self.token, self.netid, region=self.current_region)
+            sub_cmd = agent_commands.AgentCommands(agent_name, self.base_url, self.token, self.netid,
+                                                   region=self.current_region)
             sub_cmd.onecmd(work_args)
 
     def help_agent(self):
